Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6757)

Unified Diff: chrome/common/extensions/extension_message_bundle.cc

Issue 1073005: Move RTL related functions from app/l10n_util to base/i18n/rtl... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/child_process_info.cc ('k') | chrome/common/extensions/extension_message_bundle_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension_message_bundle.cc
===================================================================
--- chrome/common/extensions/extension_message_bundle.cc (revision 42180)
+++ chrome/common/extensions/extension_message_bundle.cc (working copy)
@@ -9,6 +9,7 @@
#include "app/l10n_util.h"
#include "base/hash_tables.h"
+#include "base/i18n/rtl.h"
#include "base/linked_ptr.h"
#include "base/scoped_ptr.h"
#include "base/singleton.h"
@@ -95,10 +96,10 @@
SubstitutionMap append_messages;
append_messages[kUILocaleKey] = app_locale;
// Calling l10n_util::GetTextDirection on non-UI threads doesn't seems safe,
// so we use GetTextDirectionForLocale instead.
- if (l10n_util::GetTextDirectionForLocale(app_locale.c_str()) ==
- l10n_util::RIGHT_TO_LEFT) {
+ if (base::i18n::GetTextDirectionForLocale(app_locale.c_str()) ==
+ base::i18n::RIGHT_TO_LEFT) {
append_messages[kBidiDirectionKey] = "rtl";
append_messages[kBidiReversedDirectionKey] = "ltr";
append_messages[kBidiStartEdgeKey] = kBidiRightEdgeValue;
@@ -95,10 +96,10 @@
SubstitutionMap append_messages;
append_messages[kUILocaleKey] = app_locale;
- // Calling l10n_util::GetTextDirection on non-UI threads doesn't seems safe,
+ // Calling base::i18n::GetTextDirection on non-UI threads doesn't seems safe,
// so we use GetTextDirectionForLocale instead.
« no previous file with comments | « chrome/common/child_process_info.cc ('k') | chrome/common/extensions/extension_message_bundle_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698